#! /bin/sh 
#
# 
# $Id: make-uml.sh,v 1.5 2001/10/28 23:52:22 mcr Exp $
#

# show me
set -x

# fail if any command fails
set -e

#
# configuration for this file has moved to $BUILDTOP/umlsetup.sh
# By default, that file does not exist. A sample is at umlsetup-sample.sh
# in this directory. Copy it to $BUILDTOP and edit it.
#
BUILDTOP=${BUILDTOP-../..}
if [ ! -f ${BUILDTOP}/umlsetup.sh ]
then
    echo No umlsetup.sh. Please read instructions in umlsetup-sample.sh.
    exit 1
fi

. ${BUILDTOP}/umlsetup.sh

# make absolute so that we can reference is from POOLSPACE
BUILDTOP=`cd $BUILDTOP && pwd` export BUILDTOP
FREESWANDIR=`cd $FREESWANDIR && pwd` export FREESWANDIR

if [ -d $BUILDTOP/testing/kernelconfigs ]
then
    TESTINGROOT=$BUILDTOP/testing
fi
TESTINGROOT=${TESTINGROOT-/c2/freeswan/sandbox/testing}

# okay, copy the kernel, apply the UML patches, and build a plain kernel.
UMLPLAIN=$POOLSPACE/plain
mkdir -p $UMLPLAIN

if [ ! -x $UMLPLAIN/linux ]
then
    cd $UMLPLAIN
    lndir -silent $KERNPOOL .
    
    if [ ! -d arch/um ] 
    then
	bzcat $UMLPATCH | patch -p1 
    fi

    if [ ! -f .config ] 
    then
	cp ${TESTINGROOT}/kernelconfigs/plain.config .config
    fi
    (make ARCH=um oldconfig && make ARCH=um dep && make ARCH=um linux ) || exit 1
fi

setup_host() {
    host=$1
    KERNEL=$2

    hostroot=$POOLSPACE/$host/root
    mkdir -p $hostroot
    # copy (with hard links) 
    (cd ${BASICROOT} && find . -print | cpio -pld $hostroot 2>/dev/null )

    # make sure that we have /dev, /tmp and /var/run
    mkdir -p $hostroot/dev $hostroot/tmp $hostroot/var/run $hostroot/usr/share $hostroot/proc

    # root image is debian, but FreeSWAN expects redhat
    mkdir -p $hostroot/etc/rc.d
    if [ ! -d $hostroot/etc/rc.d/init.d ]
    then
      (cd $hostroot/etc/rc.d && ln -fs ../init.d ../rc?.d . )
    fi
    
    # nuke certain other files that get in the way of booting
    rm -f $hostroot/etc/mtab
    (cd $hostroot/var/log; for i in `ls * | grep -v .bak`; do mv $i $i.bak; cp $i.bak $i; done)

    # set up the timezone
    rm -f $hostroot/etc/localtime 

    # force it to GMT
    cp /usr/share/zoneinfo/GMT $hostroot/etc/localtime

    # or, you might want to force it to local
    # cp /etc/localtime $hostroot/etc/localtime

    # copy configuration files
    ### XXX this should be done with a generated Makefile.
    (cd ${TESTINGROOT}/baseconfigs/$host && tar cf - .) | (cd $hostroot && tar -x -f - --unlink-first)

    # copy kernel.
    if [ ! -f $POOLSPACE/$host/linux ]
    then
	rm -f $POOLSPACE/$host/linux
	cp $KERNEL $POOLSPACE/$host/linux
    fi

    # make startup script
    startscript=$POOLSPACE/$host/start.sh
    if [ ! -f $startscript ]
    then
	echo '#!/bin/sh' >$startscript
	echo ''          >>$startscript
	echo '# get $net value from baseconfig'          >>$startscript
	echo ". ${TESTINGROOT}/baseconfigs/net.$host.sh" >>$startscript
	echo ''          >>$startscript
	echo "$POOLSPACE/$host/linux ubd0=$hostroot ubd1=$SHAREDIR umid=$host \$net \$*" >>$startscript
	chmod +x $startscript
    fi
}

# now, setup up root dir
for host in $REGULARHOSTS
do
    setup_host $host $UMLPLAIN/linux
done

# now, copy the kernel, apply the UML patches.
# then, make FreeSWAN patches as well.
#
UMLSWAN=$POOLSPACE/swan

# we could copy the UMLPLAIN to make this tree. This would be faster, as we
# already built most everything. We could also just use a FreeSWAN-enabled
# kernel on sunrise/sunset. We avoid this as we actually want them to always
# work.

# where to install FreeSWAN tools
DESTDIR=$POOLSPACE/root

# do not generate .depend by default
KERNDEP=''

mkdir -p $UMLSWAN

if [ ! -x $UMLSWAN/linux ]
then
    cd $UMLSWAN
    lndir -silent $KERNPOOL .
    
    if [ ! -d arch/um ] 
    then
	bzcat $UMLPATCH | patch -p1 
    fi

    if [ ! -f .config ] 
    then
	cp ${TESTINGROOT}/kernelconfigs/swan.config .config
    fi

    # make the kernel here for good luck
    make ARCH=um oldconfig
    if [ ! -f .depend ]
    then
      make ARCH=um dep
    fi 
    make ARCH=um linux
    
    # nuke final executable here since we will do FreeSWAN in a moment.
    rm -f linux .depend
    KERNDEP=dep
fi

if [ ! -f $FREESWANDIR/Makefile ] || [ ! -f $FREESWANDIR/pluto/version.c ]
then
  if [ ! -f $FREESWANDIR/top/Makefile ]
  then
	    echo "No Makefile and no top/Makefile. You must check out 'all'!"
	    exit 10
  fi
  cd $FREESWANDIR 
  ln -sf top/* . 
  for vdir in utils pluto klips/net/ipsec 
  do
	 ln -f top/version.c $vdir
  done
fi

if [ ! -d $UMLSWAN/net/ipsec ] || [ ! -x $UMLSWAN/linux ]
then
    cd $FREESWANDIR || exit 1

    make KERNMAKEOPTS='ARCH=um' KERNELSRC=$UMLSWAN KERNCLEAN='' KERNDEP=$KERNDEP KERNEL=linux DESTDIR=$DESTDIR oldgo || exit 1
fi

cd $FREESWANDIR || exit 1

# now, setup up root dir
for host in $FREESWANHOSTS
do
    setup_host $host $UMLSWAN/linux
    cd $FREESWANDIR && make DESTDIR=$POOLSPACE/$host/root install
    cd $FREESWANDIR/utils && make DESTDIR=$POOLSPACE/$host/root setup4
done




    
    
    
#
# $Log: make-uml.sh,v $
# Revision 1.5  2001/10/28 23:52:22  mcr
# 	pathnames need to be fully qualified.
#
# Revision 1.4  2001/10/23 16:32:08  mcr
# 	make log files unique to each UML.
#
# Revision 1.3  2001/10/15 05:41:46  mcr
# 	moved variables for UML setup to common file.
# 	provided sample of this file.
#
# Revision 1.2  2001/09/25 01:09:53  mcr
# 	some minor changes to whether to run "KERNDEP"
#
# Revision 1.1  2001/09/25 00:52:16  mcr
# 	a script to build a UML+FreeSWAN testing environment.
#
#    
    

    



#! /usr/pkg/bin/zsh -f
